/***LOOKING AT 10-YEAR CHANGES***/
/*runs regression and outfiles data for graph*/

drop _all

set mat 400
set memory 15m
set more 1

use mig_cps
keep if year==80|year==90

*name the covariates so they're easy to use and change
for unem manu mdy tjul tjan rain blck hown hs sa0 sa18 sa25 sa45, ltype(any) noheader: qui gen q1@=@_10
for unem mdy blck sa0 sa18 sa25 sa45, ltype(any) noheader: qui gen q2@=@_10
qui tab year, gen(yy)
qui tab cityid, gen(cc)
qui tab regiyear, gen(ry)

reg d10_pop c10_crim q1* yy* rr* [aweight=cit_pop]
predict resid
drop if resid==.

keep year d10_pop c10_crim d20_spop c10_scr cit_pop cityid pc_cr* pcsc* q1* q2* yy* rr* cc* insmp ry*

sort year
summ d10_pop c10_crim
by year: summ d10_pop c10_crim
by year: summ cit_pop pc_crim, detail

*outfile data for graph
plot d10_pop c10_crim
reg d10_pop c10_crim 
predict fit1
egen temp=mean(d10_pop), by (cityid)
gen tempd=d10_pop-temp
drop temp
egen temp=mean(c10_cr), by (cityid)
gen tempi=c10_cr-temp
drop temp
plot tempd tempi
reg tempd tempi
predict fit2
outfile cityid city c10_crim d10_pop fit1 tempi tempd fit2 using mig_cps1.raw, comma replace

*get summary statistics
summ cit_pop pc_crim q1* d10_pop c10_crim 
for cit_pop pc_crim q1unem q1manu q1mdy q1hown q1hs q1blck q1sa0 q1sa18 q1sa25 q1sa45 q1tjul q1tjan q1rain d10_pop: egen v@=mean(@), by (cityid)
egen vc10crim=mean(c10_crim), by (cityid)
for cit_pop pc_crim q1unem q1manu q1mdy q1hown q1hs q1blck q1sa0 q1sa18 q1sa25 q1sa45 q1tjul q1tjan q1rain d10_pop: gen x@=@-v@
gen xc10crim=c10_crim-vc10crim
summ xcit_pop xpc_crim xq1unem xq1manu xq1mdy xq1tjul xq1tjan xq1rain xq1blck xq1hown xq1hs xq1sa0 xq1sa18 xq1sa25 xq1sa45 xd10_pop xc10crim
corr xq1mdy xc10crim xcit_pop
drop x* v*

*with covariates in levels
reg d10_pop c10_crim yy* rr* [aweight=cit_pop]
reg d10_pop c10_crim yy* rr* cc* [aweight=cit_pop]
reg d10_pop c10_crim q1* yy* rr* [aweight=cit_pop]
reg d10_pop c10_crim q2* yy* cc* [aweight=cit_pop]
reg d10_pop c10_crim q1* yy* rr* [aweight=cit_pop] if insmp==1
reg d10_pop c10_crim q2* yy* cc* [aweight=cit_pop] if insmp==1

*adding region-year interactions
reg d10_pop c10_crim ry* [aweight=cit_pop]
reg d10_pop c10_crim ry* cc* [aweight=cit_pop]
reg d10_pop c10_crim q1* ry* [aweight=cit_pop]
reg d10_pop c10_crim q2* ry* cc* [aweight=cit_pop]
reg d10_pop c10_crim q1* ry* [aweight=cit_pop] if insmp==1
reg d10_pop c10_crim q2* ry* cc* [aweight=cit_pop] if insmp==1
