/*This program runs annual-level regressions*/

drop _all
set mat 400
set maxvar 1000 width 3000 maxobs 5000
set more 1

use mig_cps
drop if year<73

for unem mdy blck sa0 sa18 sa25 sa45 tjul tjan rain, noheader: qui gen q1@=@_1
for unem mdy blck sa0 sa18 sa25 sa45, noheader: qui gen q2@=@_1
for unem mdy blck sa0 sa18 sa25 sa45, noheader: qui gen q3@=c1_@

tab regiyear, gen(ry)
keep cityid year d1_pop c1_crim c1_scr pc_cr_1 pc_cr_2 pc_cr_3 pcscr_1 d2_spop cit_pop q1* q2* q3* pc_crim pc_scr dz1* dz2* z_ccomit z_rele insmp year cityid regiyear rr* state ry*
qui regress d1_pop c1_crim c1_scr pc_cr_1 pcscr_1 q1* [aweight=cit_pop]
predict resid
drop if resid==.
drop resid
for dz1_ccom dz2_ccom dz1_rele dz2_rele, noheader: drop if @==.

qui tab year, gen(yy)
qui tab cityid, gen(cc)

summ cit_pop pc_crim pc_scr q1* z_ccomit z_rele d1_pop c1_crim c1_scr dz1_c* dz1_r*
for cit_pop pc_crim pc_scr q1unem q1mdy q1blck q1sa0 q1sa18 q1sa25 q1sa45 q1tjul q1tjan q1rain z_rele d1_pop c1_crim c1_scr: egen v@=mean(@), by (cityid)
for cit_pop pc_crim pc_scr q1unem q1mdy q1blck q1sa0 q1sa18 q1sa25 q1sa45 q1tjul q1tjan q1rain z_rele d1_pop c1_crim c1_scr: gen x@=@-v@
egen vzccomit=mean(z_ccomit), by (cityid)
egen vdz1ccom=mean(dz1_ccom), by (cityid)
egen vdz1rele=mean(dz1_rele), by (cityid)
gen xzccomit=z_ccomit-vzccomit
gen xdz1ccom=dz1_ccom-vdz1ccom
gen xdz1rele=dz1_rele-vdz1rele
summ x*
drop x* v*

*running versions that match introductory decadal regressions

/*first with just region and year dummies*/
regress d1_pop c1_crim yy* rr* [aweight=cit_pop]
regress d1_pop c1_crim yy* rr* cc* [aweight=cit_pop]

/*level controls*/
regress d1_pop c1_crim q1* yy* rr* [aweight=cit_pop]
reg d1_pop c1_crim q2* yy* cc* [aweight=cit_pop]
regress d1_pop c1_crim q1* ry* [aweight=cit_pop]
reg d1_pop c1_crim q2* ry* cc* [aweight=cit_pop]
regress d1_pop c1_crim q1* yy* rr* [aweight=cit_pop] if insmp==1
regress d1_pop c1_crim q2* yy* cc* [aweight=cit_pop] if insmp==1

*trying extensions

*1) adding 3 lags of crime variables
regress d1_pop c1_crim pc_cr_1 pc_cr_2 pc_cr_3 q1* yy* rr* [aweight=cit_pop]
reg d1_pop c1_crim pc_cr_1 pc_cr_2 pc_cr_3 q2* yy* cc* [aweight=cit_pop]

*2) adding suburban crime
regress d1_pop c1_crim c1_scr q1* yy* rr* [aweight=cit_pop]
reg d1_pop c1_crim c1_scr q2* yy* cc* [aweight=cit_pop]

*3) adding the lagged change in state population
regress d1_pop c1_crim d2_spop q1* yy* rr* [aweight=cit_pop]
reg d1_pop c1_crim d2_spop q2* yy* cc* [aweight=cit_pop]

*4) adding all controls in levels and changes
regress d1_pop c1_crim q1* q3* yy* rr* [aweight=cit_pop]
reg d1_pop c1_crim q2* q3* yy* cc* [aweight=cit_pop]
